<p align="center">
  <a href="https://github.com/KimigaiiWuyi/GenshinUID/"><img src="https://s2.loli.net/2023/03/25/bareSdYcsmRPOyZ.png" width="256" height="256" alt="GenshinUID"></a>
</p>
<h1 align = "center">GenshinUID 4.0</h1>
<h4 align = "center">✨支持OneBot(QQ)、QQ频道、微信、开黑啦、Telegram的全功能原神Bot插件✨</h4>
<div align = "center">
        <a href="http://docs.gsuid.gbots.work/#/" target="_blank">安装文档</a> &nbsp; · &nbsp;
        <a href="http://docs.gsuid.gbots.work/#/CommandList" target="_blank">指令列表</a> &nbsp; · &nbsp;
        <a href="http://docs.gsuid.gbots.work/#/FAQ">常见问题</a>
</div>
<p align="center">
  <a><img src="https://s2.loli.net/2023/03/26/76oWuYJwg18aXL2.jpg"></a>
</p>

## 丨感谢

- [PaimonBot](https://github.com/XiaoMiku01/PaimonBot) - 插件原始代码来自于它
- *[MiniGG](https://www.minigg.cn/)* - Wiki API来自于它/插件初始化下载站来自于它
- [@MingxuanGame](https://github.com/MingxuanGame)
  - [Nonebot2-beta1](https://github.com/KimigaiiWuyi/GenshinUID/tree/nonebot2-beta1)分支新建与维护
- [@shirokurakana](https://github.com/shirokurakana)
  - [Nonebot2-beta1分支的修复与优化](https://github.com/KimigaiiWuyi/GenshinUID/pull/118)
- [@twfx1207](https://github.com/twfx1207) - 国际服相关功能的支持([#366](https://github.com/KimigaiiWuyi/GenshinUID/pull/366))
- [@猫冬](https://bbs.mihoyo.com/ys/accountCenter/postList?id=74019947) - 原神攻略的**授权**使用
- [@blue菌hehe](https://bbs.mihoyo.com/ys/accountCenter/postList?id=160367110) - 参考面板的**授权**使用
- [@音尘绝LiuSXwww](https://bbs.mihoyo.com/ys/accountCenter/postList?id=271681956) - 怪物数据表的**授权**使用
- [@Asgater](https://www.miyoushe.com/ys/accountCenter/postList?id=79695828) - 原牌图鉴的**授权**使用
- [虚空数据库](https://akashadata.com/) - 深渊出场数据的**授权**使用
- [@lgc233](https://github.com/lgc2333) - 众多优秀PR贡献
- [@lulu666lulu](https://github.com/lulu666lulu) - DS算法提供和验证码方案提供
- [@Monst.x](https://github.com/monsterxcn) - [fastapi-genshin-map](https://github.com/KimigaiiWuyi/fastapi_genshin_map)的内容填充和本体的修复
- [@CMHopeSunshine](https://github.com/CMHopeSunshine) - 随机图API提供
- [@Enka.Network](https://enka.shinshin.moe/) - 展柜面板的数据来源
- [@Ice-Cirno](https://github.com/Ice-Cirno) - Hoshino分支的修复与完善
- [@AMEKENN](https://github.com/AMEKENN) - 米游社签到部分的代码指导
- [@RemKeeper](https://github.com/RemKeeper) - 简易Cookies获取文档
- [@珊瑚宫千花](https://space.bilibili.com/398528056) - 角色别名Json提供
- [@wudifeixue](https://github.com/wudifeixue) - PR贡献 & Bug报告
- [@ZhouYingSASA](https://github.com/ZhouYingSASA) - PR贡献 & Bug报告

## 丨其他

+ 如果对本插件有功能建议&Bug报告，欢迎提Issue & Pr，每一条都会详细看过
+ 如果本插件对你有帮助，不要忘了点个Star~
+ 本项目仅供学习使用，请勿用于商业用途
+ [爱发电](https://afdian.net/@KimigaiiWuyi)
+ [GPL-3.0 License](https://github.com/KimigaiiWuyi/GenshinUID/blob/main/LICENSE) ©[@KimigaiiWuyi](https://github.com/KimigaiiWuyi)
